<?php

namespace B2buy\Buyer\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Buyer\Http\Requests\BuyerRequest;
use B2buy\Buyer\Interfaces\BuyerRepositoryInterface;
use B2buy\Buyer\Models\Buyer;
use B2buy\Buyer\Forms\Buyer as Form;

/**
 * APIController  class for buyer.
 */
class BuyerAPIController extends BaseController
{

    /**
     * Initialize buyer resource controller.
     *
     * @param type BuyerRepositoryInterface $buyer
     *
     * @return null
     */
    public function __construct(BuyerRepositoryInterface $buyer)
    {
        parent::__construct();
        $this->repository = $buyer;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Buyer\Repositories\Criteria\BuyerResourceCriteria::class);
    }

    /**
     * Display a list of buyer.
     *
     * @return Response
     */
    public function index(BuyerRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Buyer\Repositories\Presenter\BuyerPresenter::class)
            ->paginate();
    }

    /**
     * Display buyer.
     *
     * @param Request $request
     * @param Model   $buyer
     *
     * @return Response
     */
    public function show(BuyerRequest $request, Buyer $buyer)
    {
        return $buyer->setPresenter(\B2buy\Buyer\Repositories\Presenter\BuyerListPresenter::class);
        ;
    }

    /**
     * Create new buyer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BuyerRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('buyer::buyer.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('buyer/buyer/' . $buyer->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('buyer/buyer');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the buyer.
     *
     * @param Request $request
     * @param Model   $buyer
     *
     * @return Response
     */
    public function update(BuyerRequest $request, Buyer $buyer)
    {
        try {
            $data = $request->all();

            $buyer->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('buyer::buyer.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('buyer/buyer/' . $buyer->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('buyer/buyer/' . $buyer->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the buyer.
     *
     * @param Model   $buyer
     *
     * @return Response
     */
    public function destroy(BuyerRequest $request, Buyer $buyer)
    {
        try {
            $buyer->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('buyer::buyer.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('buyer/buyer/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('buyer/buyer/' . $buyer->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
