<?php

namespace B2buy\Buyer\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Buyer\Models\Buyer;

class BuyerPolicy
{

    /**
     * Determine if the given user can view the buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Buyer $buyer)
    {
        if ($user->canDo('buyer.buyer.view') && $user->isAdmin()) {
            return true;
        }

        return $buyer->user_id == user_id() && $buyer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buyer.buyer.create');
    }

    /**
     * Determine if the given user can update the given buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Buyer $buyer)
    {
        if ($user->canDo('buyer.buyer.edit') && $user->isAdmin()) {
            return true;
        }

        return $buyer->user_id == user_id() && $buyer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Buyer $buyer)
    {
        return $buyer->user_id == user_id() && $buyer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Buyer $buyer)
    {
        if ($user->canDo('buyer.buyer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buyer.
     *
     * @param UserPolicy $user
     * @param Buyer $buyer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Buyer $buyer)
    {
        if ($user->canDo('buyer.buyer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
