<?php

namespace B2buy\Buyer\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Buyer\Models\Costcenter;

class CostcenterPolicy
{

    /**
     * Determine if the given user can view the costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function view(UserPolicy $user, Costcenter $costcenter)
    {
        if ($user->canDo('buyer.costcenter.view') && $user->isAdmin()) {
            return true;
        }

        return $costcenter->user_id == user_id() && $costcenter->user_type == user_type();
    }

    /**
     * Determine if the given user can create a costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buyer.costcenter.create');
    }

    /**
     * Determine if the given user can update the given costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function update(UserPolicy $user, Costcenter $costcenter)
    {
        if ($user->canDo('buyer.costcenter.edit') && $user->isAdmin()) {
            return true;
        }

        return $costcenter->user_id == user_id() && $costcenter->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Costcenter $costcenter)
    {
        return $costcenter->user_id == user_id() && $costcenter->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Costcenter $costcenter)
    {
        if ($user->canDo('buyer.costcenter.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given costcenter.
     *
     * @param UserPolicy $user
     * @param Costcenter $costcenter
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Costcenter $costcenter)
    {
        if ($user->canDo('buyer.costcenter.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
