<?php

namespace B2buy\Buyer\Providers;

use Illuminate\Support\ServiceProvider;

class BuyerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'buyer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'buyer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerBuyer();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerBuyer()
    {
        $this->app->bind('buyer', function($app) {
            return new Buyer($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Buyer', 'Lavalite\Buyer\Facades\Buyer');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('b2buy.buyer', function ($app) {
            return $this->app->make('B2buy\Buyer\Buyer');
        });

        // Bind Buyer to repository
        $this->app->bind(
            'B2buy\Buyer\Interfaces\BuyerRepositoryInterface',
            \B2buy\Buyer\Repositories\Eloquent\BuyerRepository::class
        );        // Bind Costcenter to repository
        $this->app->bind(
            'B2buy\Buyer\Interfaces\CostcenterRepositoryInterface',
            \B2buy\Buyer\Repositories\Eloquent\CostcenterRepository::class
        );

        $this->app->register(\B2buy\Buyer\Providers\AuthServiceProvider::class);
        
        $this->app->register(\B2buy\Buyer\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and buyer's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.buyer'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeBuyer::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.buyer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('b2buy/buyer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/buyer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/buyer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
