<?php

namespace B2buy\Buyer\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use B2buy\Buyer\Models\Buyer;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'B2buy\Buyer\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/buyer/buyer/*')) {
            Route::bind('buyer', function ($buyer) {
                $buyerrepo = $this->app->make('B2buy\Buyer\Interfaces\BuyerRepositoryInterface');
                return $buyerrepo->findorNew($buyer);
            });
        }
        if (Request::is('*/buyer/costcenter/*')) {
            Route::bind('costcenter', function ($costcenter) {
                $costcenterrepo = $this->app->make('B2buy\Buyer\Interfaces\CostcenterRepositoryInterface');
                return $costcenterrepo->findorNew($costcenter);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
